==> scalarx_2.10-0.2.1-JS.jar: rx/core/0003-Dynamic$State.js <==
/** @constructor */
ScalaJS.c.rx_core_Dynamic$State = (function() {
  ScalaJS.c.rx_ops_Incrementing$SpinState.call(this);
  this.parents$2 = null;
  this.level$2 = ScalaJS.modules.scala_scalajs_runtime_Long().zero__Lscala_scalajs_runtime_Long()
});
ScalaJS.c.rx_core_Dynamic$State.prototype = new ScalaJS.inheritable.rx_ops_Incrementing$SpinState();
ScalaJS.c.rx_core_Dynamic$State.prototype.constructor = ScalaJS.c.rx_core_Dynamic$State;
ScalaJS.c.rx_core_Dynamic$State.prototype.parents__Lscala_collection_Seq = (function() {
  return this.parents$2
});
ScalaJS.c.rx_core_Dynamic$State.prototype.level__J = (function() {
  return this.level$2
});
ScalaJS.c.rx_core_Dynamic$State.prototype.rx$core$Dynamic$State$$$outer__Lrx_core_Dynamic = (function() {
  return ScalaJS.as.rx_core_Dynamic(this.$$outer$f)
});
ScalaJS.c.rx_core_Dynamic$State.prototype.init___Lrx_core_Dynamic__Lscala_collection_Seq__J__J__Lscala_util_Try = (function($$outer, parents, level, timestamp, value) {
  this.parents$2 = parents;
  this.level$2 = level;
  ScalaJS.c.rx_ops_Incrementing$SpinState.prototype.init___Lrx_ops_Incrementing__J__Lscala_util_Try.call(this, $$outer, timestamp, value);
  return this
});
ScalaJS.c.rx_core_Dynamic$State.prototype.parents = (function() {
  return this.parents__Lscala_collection_Seq()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.level = (function() {
  return this.level__J()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.rx$core$Dynamic$State$$$outer = (function() {
  return this.rx$core$Dynamic$State$$$outer__Lrx_core_Dynamic()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.rx$core$Dynamic$State$$$outer__ = (function() {
  return this.rx$core$Dynamic$State$$$outer__Lrx_core_Dynamic()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.level__ = (function() {
  return ScalaJS.bJ(this.level__J())
});
ScalaJS.c.rx_core_Dynamic$State.prototype.parents__ = (function() {
  return this.parents__Lscala_collection_Seq()
});
/** @constructor */
ScalaJS.inheritable.rx_core_Dynamic$State = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Dynamic$State.prototype = ScalaJS.c.rx_core_Dynamic$State.prototype;
/** @constructor */
ScalaJS.classes.rx_core_Dynamic$State = (function(arg$1, arg$2, arg$3, arg$4, arg$5) {
  ScalaJS.c.rx_core_Dynamic$State.call(this);
  return this.init___Lrx_core_Dynamic__Lscala_collection_Seq__J__J__Lscala_util_Try(arg$1, arg$2, arg$3, arg$4, arg$5)
});
ScalaJS.classes.rx_core_Dynamic$State.prototype = ScalaJS.c.rx_core_Dynamic$State.prototype;
ScalaJS.is.rx_core_Dynamic$State = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Dynamic$State)))
});
ScalaJS.as.rx_core_Dynamic$State = (function(obj) {
  if ((ScalaJS.is.rx_core_Dynamic$State(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Dynamic$State")
  }
});
ScalaJS.isArrayOf.rx_core_Dynamic$State = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Dynamic$State)))
});
ScalaJS.asArrayOf.rx_core_Dynamic$State = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Dynamic$State(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Dynamic$State;", depth)
  }
});
ScalaJS.data.rx_core_Dynamic$State = new ScalaJS.ClassTypeData({
  rx_core_Dynamic$State: 0
}, false, "rx.core.Dynamic$State", ScalaJS.data.rx_ops_Incrementing$SpinState, {
  rx_core_Dynamic$State: 1,
  rx_ops_Incrementing$SpinState: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Dynamic$State.prototype.$classData = ScalaJS.data.rx_core_Dynamic$State;
//@ sourceMappingURL=0003-Dynamic$State.js.map

==> scalarx_2.10-0.2.2-JS.jar: rx/core/0003-Dynamic$State.js <==
/** @constructor */
ScalaJS.c.rx_core_Dynamic$State = (function() {
  ScalaJS.c.rx_core_Incrementing$SpinState.call(this);
  this.parents$2 = null;
  this.level$2 = ScalaJS.modules.scala_scalajs_runtime_Long().zero__Lscala_scalajs_runtime_Long()
});
ScalaJS.c.rx_core_Dynamic$State.prototype = new ScalaJS.inheritable.rx_core_Incrementing$SpinState();
ScalaJS.c.rx_core_Dynamic$State.prototype.constructor = ScalaJS.c.rx_core_Dynamic$State;
ScalaJS.c.rx_core_Dynamic$State.prototype.parents__Lscala_collection_Seq = (function() {
  return this.parents$2
});
ScalaJS.c.rx_core_Dynamic$State.prototype.level__J = (function() {
  return this.level$2
});
ScalaJS.c.rx_core_Dynamic$State.prototype.rx$core$Dynamic$State$$$outer__Lrx_core_Dynamic = (function() {
  return ScalaJS.as.rx_core_Dynamic(this.$$outer$f)
});
ScalaJS.c.rx_core_Dynamic$State.prototype.init___Lrx_core_Dynamic__Lscala_collection_Seq__J__J__Lscala_util_Try = (function($$outer, parents, level, timestamp, value) {
  this.parents$2 = parents;
  this.level$2 = level;
  ScalaJS.c.rx_core_Incrementing$SpinState.prototype.init___Lrx_core_Incrementing__J__Lscala_util_Try.call(this, $$outer, timestamp, value);
  return this
});
ScalaJS.c.rx_core_Dynamic$State.prototype.parents = (function() {
  return this.parents__Lscala_collection_Seq()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.level = (function() {
  return this.level__J()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.rx$core$Dynamic$State$$$outer = (function() {
  return this.rx$core$Dynamic$State$$$outer__Lrx_core_Dynamic()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.rx$core$Dynamic$State$$$outer__ = (function() {
  return this.rx$core$Dynamic$State$$$outer__Lrx_core_Dynamic()
});
ScalaJS.c.rx_core_Dynamic$State.prototype.level__ = (function() {
  return ScalaJS.bJ(this.level__J())
});
ScalaJS.c.rx_core_Dynamic$State.prototype.parents__ = (function() {
  return this.parents__Lscala_collection_Seq()
});
/** @constructor */
ScalaJS.inheritable.rx_core_Dynamic$State = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Dynamic$State.prototype = ScalaJS.c.rx_core_Dynamic$State.prototype;
/** @constructor */
ScalaJS.classes.rx_core_Dynamic$State = (function(arg$1, arg$2, arg$3, arg$4, arg$5) {
  ScalaJS.c.rx_core_Dynamic$State.call(this);
  return this.init___Lrx_core_Dynamic__Lscala_collection_Seq__J__J__Lscala_util_Try(arg$1, arg$2, arg$3, arg$4, arg$5)
});
ScalaJS.classes.rx_core_Dynamic$State.prototype = ScalaJS.c.rx_core_Dynamic$State.prototype;
ScalaJS.is.rx_core_Dynamic$State = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Dynamic$State)))
});
ScalaJS.as.rx_core_Dynamic$State = (function(obj) {
  if ((ScalaJS.is.rx_core_Dynamic$State(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Dynamic$State")
  }
});
ScalaJS.isArrayOf.rx_core_Dynamic$State = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Dynamic$State)))
});
ScalaJS.asArrayOf.rx_core_Dynamic$State = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Dynamic$State(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Dynamic$State;", depth)
  }
});
ScalaJS.data.rx_core_Dynamic$State = new ScalaJS.ClassTypeData({
  rx_core_Dynamic$State: 0
}, false, "rx.core.Dynamic$State", ScalaJS.data.rx_core_Incrementing$SpinState, {
  rx_core_Dynamic$State: 1,
  rx_core_Incrementing$SpinState: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Dynamic$State.prototype.$classData = ScalaJS.data.rx_core_Dynamic$State;
//@ sourceMappingURL=0003-Dynamic$State.js.map
